@@ -1,8 +1,6 @@
 package Catmandu::MAB2;
 
-#ABSTRACT: Catmandu modules for working with MAB2 data.
-
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 use strict;
 use warnings;
@@ -20,9 +18,14 @@ __END__
 
 Catmandu::MAB2 - Catmandu modules for working with MAB2 data.
 
-=head1 VERSION
+=begin markdown
 
-version 0.07
+[![Build Status](https://travis-ci.org/jorol/Catmandu-MAB2.png)](https://travis-ci.org/jorol/Catmandu-MAB2)
+[![Coverage Status](https://coveralls.io/repos/jorol/Catmandu-MAB2/badge.png?branch=devel)](https://coveralls.io/r/jorol/Catmandu-MAB2?branch=devel)
+[![Kwalitee Score](http://cpants.cpanauthors.org/dist/Catmandu-MAB2.png)](http://cpants.cpanauthors.org/dist/Catmandu-MAB2)
+[![CPAN version](https://badge.fury.io/pl/Catmandu-MAB2.png)](http://badge.fury.io/pl/Catmandu-MAB2)
+
+=end markdown
 
 =head1 DESCRIPTION
 
